@@ -44,7 +44,10 @@ class ETTrainer:
         self._load_checkpoint(self.cache['log_dir'] + _sep + self.cache['checkpoint'])
 
     def _load_checkpoint(self, full_path):
-        chk = _torch.load(full_path)
+        try:
+            chk = _torch.load(full_path)
+        except:
+            chk = _torch.load(full_path, map_location='cpu')
         try:
             self.nn['model'].module.load_state_dict(chk)
         except:
@@ -140,7 +143,7 @@ class ETTrainer:
                     score.accumulate(it['scores'])
                     eval_loss.accumulate(it['avg_loss'])
                     if save_pred:
-                        its.append([it])
+                        its.append(it)
                     if self.args['debug'] and len(dataset_list) <= 1 and i % int(_math.log(i + 1) + 1) == 0:
                         print(f"Itr:{i}/{len(loader)}, {it['avg_loss'].average}, {it['scores'].scores()}")
 
